<?php

namespace Controllers;

use Services\OrderAFService as Service;

class OrderAFController
{

    private $dataSetErrors;
    private $cdOrder;

    public function __construct(Service $service)
    {
        $this->service = $service;
    }

    public function saveOrder($orderData, $cdSupplier)
    {
        $supplier = $this->service->getSupplier($cdSupplier)[0];
        $this->service->setAutoForn($orderData, $supplier);
        if ($supplier['IDTPFORPGTFO'] == 'V') {
            $this->service->setDeadlinePayment($orderData, $cdSupplier);
        }

    }

    public function validatesDataAF($order, $cdSupplier)
    {
        $this->cdOrder = (string)$order->numero;
        $this->dataSetErrors = [];
        $validOrder = self::validatesOrderRepeated($cdSupplier);
        if ($validOrder) {
            self::validatesSupplier($cdSupplier);
        }
        return $this->dataSetErrors;
    }

    public function getNewCodeAutoForne()
    {
        return $this->service->generateCodeAutoForn();
    }

    private function validatesOrderRepeated($cdSupplier)
    {
        $autoFornUsr = $this->service->getAutoFornUsr($this->cdOrder, $cdSupplier);
        if (!empty($autoFornUsr)) {
            self::setErrorOnDataset('AF já foi incluída no sistema!');
            
            return false;
        }
        
        return true;
    }

    private function validatesSupplier($cdSupplier)
    {
        $supplier = $this->service->getSupplier($cdSupplier);
        if (empty($supplier)) {
            self::setErrorOnDataset('O fornecedor não existe.');
        } else {
            self::validatesDefaultSupplier($cdSupplier);
        }

    }

    private function validatesDefaultSupplier($cdSupplier)
    {
        $defaultSuppliers = $this->service->getDefaultSuppliers($cdSupplier);
        if (empty($defaultSuppliers)) {
            self::setErrorOnDataset("O Fornecedor $cdSupplier não está autorizado para este tipo de inclusão.");
        }

    }

    private function setErrorOnDataset($error)
    {
        array_push($this->dataSetErrors, $error);
    }

}
